@@ -34,7 +34,7 @@ setMethod ("show" , "portfolio" ,
 			.jcall(portfolio@java,returnSig="V", method="setParam","samplingInterval","last")
 			
 			portfolio_startBatch(portfolio)
-			.jcall(portfolio@java,returnSig="V", method="createCallGroup",as.integer(9))
+			.jcall(portfolio@java,returnSig="V", method="createCallGroup",as.integer(7))
 			.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="getMetric",paste('{"metric":"PORTFOLIO_PROFIT"}'))
 			.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="getMetric",paste('{"metric":"PORTFOLIO_RETURN"}'))
 			.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="getMetric",paste('{"metric":"PORTFOLIO_VALUE"}'))
@@ -73,7 +73,7 @@ util_summary(x)
 }
 setMethod("plot" ,c(x="portfolio",y="missing"),util_summaryPlot)
 
-portfolio_mainSettings<-function(portfolio){
+portfolio_defaultSettings<-function(portfolio){
 	portfolio_settings(portfolio,portfolioMetricsMode="portfolio",
 				windowLength = "1d",
 				holdingPeriodsOnly = FALSE,
@@ -142,6 +142,25 @@ for(i in 1:length(change)){
 }
 }
 
+portfolio_settingsRiskMetrics<-function(portfolio){
+	portfolio_settings(portfolio,portfolioMetricsMode="price",
+			windowLength = "1s",
+			holdingPeriodsOnly = FALSE,
+			shortSalesMode = "lintner",
+			jumpsModel = "none",
+			noiseModel = FALSE,
+			fractalPriceModel=FALSE,
+			factorModel = "sim",
+			densityModel="NORMAL",
+			driftTerm=FALSE,
+			resultsSamplingInterval = "1d",
+			inputSamplingInterval="1d",
+			timeScale="1d",
+			txnCostPerShare=0,
+			txnCostFixed=0)
+	.jcall(portfolio@java,returnSig="V", method="setParam","riskMethodology", "RiskMetrics")
+}
+
 portfolio_getSettings<-function(portfolio){
 
 	temp<-list()
@@ -162,64 +181,6 @@ portfolio_getSettings<-function(portfolio){
 	temp$densityModel<-.jcall(portfolio@java,returnSig="S", method="getParam","densityApproxModel")
 	temp
 }
-#portfolio_create<-function(
-#		index,fromTime,toTime,priceDataIx){
-#}
-
-#portfolio_create_funct=function(
-#		index,fromTime,toTime){
-#	util_validate()
-##	clientConnection=get('clientConnection', envir=globalenv())
-#	clientConnection=getOption('clientConnection')
-#	portfolio=new("portfolio", java=.jnew("com.portfolioeffect.quant.client.portfolio.Portfolio",clientConnection),optimization_info=NULL)
-#	result<-.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="setFromTime", fromTime)
-#	util_checkErrors(result)
-#	result<-.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="setToTime", toTime)
-#	util_checkErrors(result)
-#	result<-.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="addIndex", index)
-#	util_checkErrors(result)
-#	portfolio_mainSettings(portfolio)
-#	return(portfolio)
-#}
-#portfolio_create_functSPY=function(fromTime,toTime){
-#	portfolio_create_funct("SPY",fromTime,toTime)
-#}
-#portfolio_create_funct_SPY=function(index,fromTime){
-#	portfolio_create_funct("SPY",index,fromTime)
-#}
-
-#setMethod("portfolio_create" ,c(index="character",fromTime="character",toTime="character",priceDataIx="missing"),portfolio_create_funct)
-#setMethod("portfolio_create" ,c(index="missing",fromTime="character",toTime="character",priceDataIx="missing"),portfolio_create_functSPY)
-#setMethod("portfolio_create" ,c(index="character",fromTime="character",toTime="missing",priceDataIx="missing"),portfolio_create_funct_SPY)
-		
-#setMethod("portfolio_create" ,c(index="missing",fromTime="missing",toTime="missing",priceDataIx="matrix"),function(
-#				priceDataIx){
-#			util_validate()
-#			clientConnection=getOption('clientConnection')
-#			portfolio=new("portfolio", java=.jnew("com.portfolioeffect.quant.client.portfolio.Portfolio",clientConnection),optimization_info=NULL)
-#			result<-.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="addIndex", as.double(priceDataIx[,2]),.jlong(priceDataIx[,1]))
-#			util_checkErrors(result)
-#			portfolio_mainSettings(portfolio)
-#			return(portfolio)
-#		})
-#
-#setMethod("portfolio_create" ,c(index="matrix",fromTime="missing",toTime="missing",priceDataIx="missing"),function(
-#				index){
-#			util_validate()
-#			clientConnection=getOption('clientConnection')
-#			portfolio=new("portfolio", java=.jnew("com.portfolioeffect.quant.client.portfolio.Portfolio",clientConnection),optimization_info=NULL)
-#			result<-.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="addIndex", as.double(index[,2]),.jlong(index[,1]))
-#			util_checkErrors(result)
-#			portfolio_mainSettings(portfolio)
-#			return(portfolio)
-#		})
-
-#setMethod("portfolio_create" ,c(index="portfolio",fromTime="missing",toTime="missing",priceDataIx="missing"),function(
-#				index){
-#			util_validate()
-#			portfolio=new("portfolio", java=.jnew("com.portfolioeffect.quant.client.portfolio.Portfolio",index@java),optimization_info=NULL)
-#			return(portfolio)
-#		})
 
 portfolio_create<-function(index=NULL,fromTime=NULL,toTime=NULL,priceDataIx=NULL){
 	
@@ -235,7 +196,7 @@ portfolio_create<-function(index=NULL,fromTime=NULL,toTime=NULL,priceDataIx=NULL
 		portfolio=new("portfolio", java=.jnew("com.portfolioeffect.quant.client.portfolio.Portfolio",clientConnection),optimization_info=NULL)
 		result<-.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="addIndex", as.double(priceDataIx[,2]),.jlong(priceDataIx[,1]))
 		util_checkErrors(result)
-		portfolio_mainSettings(portfolio)
+		portfolio_defaultSettings(portfolio)
 		return(portfolio)
 	}
 	if(((class(fromTime)=="character")&(class(toTime)=="character")&(is.null(priceDataIx)))||((class(fromTime)=="character")&(class(index)=="character")&(is.null(toTime))&(is.null(priceDataIx)))){
@@ -256,7 +217,7 @@ portfolio_create<-function(index=NULL,fromTime=NULL,toTime=NULL,priceDataIx=NULL
 		util_checkErrors(result)
 		result<-.jcall(portfolio@java,returnSig="Lcom/portfolioeffect/quant/client/result/MethodResult;", method="addIndex", index)
 		util_checkErrors(result)
-		portfolio_mainSettings(portfolio)
+		portfolio_defaultSettings(portfolio)
 		return(portfolio)
 	}
 	if((class(index)=="portfolio")&(is.null(fromTime))&(is.null(toTime))&(is.null(priceDataIx))){
